/*
 * This file is auto-generated, do not modify!
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once
#include <libfwupd/fwupd-build.h>
/**
 * FwupdJcatBlobKind:
 */
typedef enum {
    /**
     * FWUPD_JCAT_BLOB_KIND_UNKNOWN:
     */
    FWUPD_JCAT_BLOB_KIND_UNKNOWN,
    /**
     * FWUPD_JCAT_BLOB_KIND_SHA256:
     */
    FWUPD_JCAT_BLOB_KIND_SHA256,
    /**
     * FWUPD_JCAT_BLOB_KIND_GPG:
     */
    FWUPD_JCAT_BLOB_KIND_GPG,
    /**
     * FWUPD_JCAT_BLOB_KIND_PKCS7:
     */
    FWUPD_JCAT_BLOB_KIND_PKCS7,
    /**
     * FWUPD_JCAT_BLOB_KIND_SHA1:
     */
    FWUPD_JCAT_BLOB_KIND_SHA1,
    /**
     * FWUPD_JCAT_BLOB_KIND_BT_MANIFEST:
     */
    FWUPD_JCAT_BLOB_KIND_BT_MANIFEST,
    /**
     * FWUPD_JCAT_BLOB_KIND_BT_CHECKPOINT:
     */
    FWUPD_JCAT_BLOB_KIND_BT_CHECKPOINT,
    /**
     * FWUPD_JCAT_BLOB_KIND_BT_INCLUSION_PROOF:
     */
    FWUPD_JCAT_BLOB_KIND_BT_INCLUSION_PROOF,
    /**
     * FWUPD_JCAT_BLOB_KIND_BT_VERIFIER:
     */
    FWUPD_JCAT_BLOB_KIND_BT_VERIFIER,
    /**
     * FWUPD_JCAT_BLOB_KIND_ED25519:
     */
    FWUPD_JCAT_BLOB_KIND_ED25519,
    /**
     * FWUPD_JCAT_BLOB_KIND_SHA512:
     */
    FWUPD_JCAT_BLOB_KIND_SHA512,
    /**
     * FWUPD_JCAT_BLOB_KIND_BT_LOGINDEX:
     */
    FWUPD_JCAT_BLOB_KIND_BT_LOGINDEX,
}  FwupdJcatBlobKind;
#define FWUPD_JCAT_BLOB_KIND_LAST 12
const gchar *fwupd_jcat_blob_kind_to_string(FwupdJcatBlobKind val) G_GNUC_CONST;
FwupdJcatBlobKind fwupd_jcat_blob_kind_from_string(const gchar *val) G_GNUC_CONST G_GNUC_NON_NULL(1);
/**
 * FwupdJcatBlobMethod:
 */
typedef enum {
    /**
     * FWUPD_JCAT_BLOB_METHOD_UNKNOWN:
     */
    FWUPD_JCAT_BLOB_METHOD_UNKNOWN,
    /**
     * FWUPD_JCAT_BLOB_METHOD_CHECKSUM:
     */
    FWUPD_JCAT_BLOB_METHOD_CHECKSUM,
    /**
     * FWUPD_JCAT_BLOB_METHOD_SIGNATURE:
     */
    FWUPD_JCAT_BLOB_METHOD_SIGNATURE,
}  FwupdJcatBlobMethod;
#define FWUPD_JCAT_BLOB_METHOD_LAST 3
const gchar *fwupd_jcat_blob_method_to_string(FwupdJcatBlobMethod val) G_GNUC_CONST;
/**
 * FwupdJcatBlobFlags:
 */
typedef enum {
    /**
     * FWUPD_JCAT_BLOB_FLAG_NONE:
     */
    FWUPD_JCAT_BLOB_FLAG_NONE = 0,
    /**
     * FWUPD_JCAT_BLOB_FLAG_IS_UTF8:
     */
    FWUPD_JCAT_BLOB_FLAG_IS_UTF8 = 1 << 0,
} G_GNUC_FLAG_ENUM FwupdJcatBlobFlags;
gchar *fwupd_jcat_blob_flags_to_string(FwupdJcatBlobFlags val) G_GNUC_CONST;
